# lightning-rod

[![GitHub Actions](https://github.com/reapermc/lightning-rod/workflows/CI/badge.svg)](https://github.com/reapermc/lightning-rod/actions)

> Function library for the Bolt scripting language.

## Installation

```bash
pip install lightning_rod
```

---

License - [MIT](https://github.com/reapermc/lightning-rod/blob/main/LICENSE)

